@@ -1,6 +1,8 @@
 #ifndef __Q_IBUS_TYPES_H_
 #define __Q_IBUS_TYPES_H_
 
+#include <QMetaType>
+
 namespace IBus {
 
 typedef enum
@@ -46,6 +48,19 @@ typedef enum {
     CapProperty          = 1 << 4,
 } Capabilite;
 
+typedef enum {
+    OrientationHorizontal   = 0,
+    OrientationVertical     = 1,
+    OrientationSystem       = 2,
+} Orientation;
+
+typedef struct {
+    uint x;
+    uint y;
+    uint width;
+    uint height;
+} Rectangle;
+
 };
 
 #endif
